/****************************************************************************
**  MDHashTool - Message Digest (MD5, SHA-1, etc.) tool
**  Copyright (c) 2005  Charles Melhorn
**
**  This file is part of MDHashTool.
**
**  MDHashTool is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  MDHashTool is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
**  Or see the GNU web site at: http://www.gnu.org
**
****************************************************************************/ 

var gTargetFile = null;

var nsIMDHash = Components.interfaces.nsIMDHash;
var gMDHashTool = Components.classes["@mozilla.org/mdhashtool;1"]
                  .createInstance(nsIMDHash);


function Init()
{
  var hash_type;

  var hashtype_db = document.getElementById("mdht-hashtype-dropbox"); 
  hashtype_db.value = gMDHTUserPreferenceInfo.getPrefValue("default_hash_alg");  

  if ( (window.arguments[0]) &&
       (window.arguments[0] instanceof Components.interfaces.nsIFile) )
   {
    gTargetFile = window.arguments[0];

    switch(hashtype_db.value)
    {
      case "MD5":  hash_type = nsIMDHash.HASH_MD5;
                   break;

      case "SHA1": hash_type = nsIMDHash.HASH_SHA1;
                   break;

      default:     hash_type = nsIMDHash.HASH_MD5;
                   break;
    }

    var checksum = gMDHashTool.getHashForFile(hash_type, gTargetFile);
    document.getElementById("digest1-desc").value = checksum;

    // Get IOService to convert file path to URI
    var serv = Components.classes["@mozilla.org/network/io-service;1"].
               getService(Components.interfaces.nsIIOService);

    var fileURI = serv.newFileURI(gTargetFile);
    document.getElementById("input-desc").value = fileURI.spec;

    document.getElementById("digest-ref-desc").focus();
   }

}


function getFileDigest(hash_alg)
{
  var hash_type, checksum;

  switch(hash_alg)
  {
    case "MD5":  hash_type = nsIMDHash.HASH_MD5;
                 break;

    case "SHA1": hash_type = nsIMDHash.HASH_SHA1;
                 break;

    default:     hash_type = nsIMDHash.HASH_MD5;
                 break;
  }

  if (gTargetFile)
   {
     checksum = gMDHashTool.getHashForFile(hash_type, gTargetFile);
   }

  document.getElementById("digest1-desc").value = checksum;

  compareDigests(document.getElementById("digest-ref-desc").value);
}


function compareDigests(digestString)
{
  if (digestString == "")
   {
    document.getElementById("match-indicator-img").setAttribute("match", "untested");
    document.getElementById("match-indicator-desc").value = "";
   }
  else
   {
     if (digestString == document.getElementById("digest1-desc").value)
      {
       document.getElementById("match-indicator-img").setAttribute("match", "true");
       document.getElementById("match-indicator-desc").value = "match";
      }
     else
      {
       document.getElementById("match-indicator-img").setAttribute("match", "false");
       document.getElementById("match-indicator-desc").value = "no match";
      }
   }

}


function copyStringToClipboard(aString)
{
  var clipboardHelper = Components.classes["@mozilla.org/widget/clipboardhelper;1"]
                           .getService(Components.interfaces.nsIClipboardHelper);

  clipboardHelper.copyString(aString);  
}


